/* Copyright (C) 2012 Andre Noll <maan@tuebingen.mpg.de>, see file COPYING. */

/** \file check_wav.h Detect, process and cut a wav header. */

struct check_wav_context;

/**
 * These come from the command line arguments.
 *
 * Different users of the check_wav API have different arg_info structs,
 * so we need a universal variant for these.
 */
struct wav_params {
	/** Number of channels, or the default value. */
	int channels_arg;
	/** Whether the channel count was given. */
	int channels_given;
	/** Same semantics as \a channels_count. */
	int sample_rate_arg;
	/** Whether the sample rate was given. */
	int sample_rate_given;
	/** Same semantics as \a sample_rate. */
	int sample_format_arg;
	/** Whether the sample format was given. */
	int sample_format_given;
};

#define LLS_COPY_WAV_PARMS(_dst, _pfx, _lpr) \
	(_dst)->channels_given = lls_opt_given(lls_opt_result( \
		_pfx ## _OPT_CHANNELS, (_lpr))); \
	(_dst)->sample_rate_given = lls_opt_given(lls_opt_result( \
		_pfx ## _OPT_SAMPLE_RATE, (_lpr))); \
	(_dst)->sample_format_given = lls_opt_given(lls_opt_result( \
		_pfx ## _OPT_SAMPLE_FORMAT, (_lpr))); \
	(_dst)->channels_arg = lls_uint32_val(0, lls_opt_result( \
		_pfx ## _OPT_CHANNELS, (_lpr))); \
	(_dst)->sample_rate_arg = lls_uint32_val(0, lls_opt_result( \
		_pfx ## _OPT_SAMPLE_RATE, (_lpr))); \
	(_dst)->sample_format_arg = lls_uint32_val(0, lls_opt_result( \
		_pfx ## _OPT_SAMPLE_FORMAT, (_lpr)));

struct check_wav_context *check_wav_init(struct btr_node *parent,
		struct btr_node *child, struct wav_params *params,
		struct btr_node **cw_btrn);
void check_wav_pre_select(struct sched *s, struct check_wav_context *cwc);
int check_wav_post_select(struct check_wav_context *cwc);
void check_wav_shutdown(struct check_wav_context *cwc);
